@@ -15,4 +15,8 @@ export type PromiseLike<T> = {
 function GError.new(
 	originalError: (Error & { extensions: any? }) -- new syntax
 ): GError
-end
\ No newline at end of file
+end
+
+type IProperties = {
+	RemoveOnCollision: (string | (IProperties, BasePart, Vector3, Vector3, Enum.Material, number) -> boolean)?,
+}
\ No newline at end of file
